.. artifician documentation master file, created by
   sphinx-quickstart on Sun Feb 20 23:06:29 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation
==============

.. toctree ::
   intro
   getting_started
   quick_start
   advanced_concepts
   modules
